@@ -1006,3 +1006,8 @@ if (\Froxlor\Froxlor::isFroxlorVersion('0.10.37')) {
         showUpdateStep("Updating from 0.10.37 to 0.10.38", false);
         \Froxlor\Froxlor::updateToVersion('0.10.38');
 }
+
+if (\Froxlor\Froxlor::isFroxlorVersion('0.10.38')) {
+        showUpdateStep("Updating from 0.10.38 to 0.10.38.1", false);
+        \Froxlor\Froxlor::updateToVersion('0.10.38.1');
+}
