@@ -529,7 +529,6 @@ $lng['traffic']['distribution'] = '<font color="#019522">FTP</font> | <font colo
 $lng['traffic']['sumhttp'] = 'Resumo Tráfego de HTTP em';
 $lng['traffic']['sumftp'] = 'Resumo Tráfego de FTP em';
 $lng['traffic']['summail'] = 'Resumo Tráfego de HTTP em';
-$lng['serversettings']['no_robots']['title'] = 'Aceitar robÃ´s de procura na index de seuFroxlor';
 $lng['admin']['loggersettings'] = 'Configurações de Logs';
 $lng['serversettings']['logger']['enable'] = 'Habilitar/Desabilitar Logs';
 $lng['serversettings']['logger']['severity'] = 'Nível de Logs';
@@ -555,7 +554,7 @@ $lng['panel']['reseller'] = 'Revenda';
 $lng['panel']['admin'] = 'Administrador';
 $lng['panel']['customer'] = 'Cliente(s)';
 $lng['error']['nomessagetosend'] = 'Você não entrou com uma mensagem';
-$lng['error']['noreceipientsgiven'] = 'Você não especificou um destinatário';
+$lng['error']['norecipientsgiven'] = 'Você não especificou um destinatário';
 $lng['admin']['emaildomain'] = 'Domínio de Email';
 $lng['admin']['email_only'] = 'Somente Email?';
 $lng['admin']['wwwserveralias'] = 'Adicionar um "www." ServerAlias';
@@ -563,14 +562,14 @@ $lng['admin']['ipsandports']['enable_ssl'] = 'Esta é uma porta SSL?';
 $lng['admin']['ipsandports']['ssl_cert_file'] = 'Caminho para o certificado SSL';
 $lng['panel']['send'] = 'Enviar';
 $lng['admin']['subject'] = 'Assunto';
-$lng['admin']['receipient'] = 'Destinatário';
+$lng['admin']['recipient'] = 'Destinatário';
 $lng['admin']['message'] = 'Escrever uma mensagem';
 $lng['admin']['text'] = 'Mensagem';
 $lng['menu']['message'] = 'Mensagens';
 $lng['error']['errorsendingmail'] = 'A mensagem para "%s" falhou';
 $lng['error']['cannotreaddir'] = 'Não é possível ler o diretório "%s"';
 $lng['message']['success'] = 'Mensagens enviadas para %s destinatários com sucesso';
-$lng['message']['noreceipients'] = 'Email não enviado porque não tem destinatário no banco de dados';
+$lng['message']['norecipients'] = 'Email não enviado porque não tem destinatário no banco de dados';
 $lng['admin']['sslsettings'] = 'Configuração de SSL';
 $lng['cronjobs']['notyetrun'] = 'Ainda não está rodando';
 $lng['serversettings']['default_vhostconf']['title'] = 'Configuração de Vhost padrão';
